@@ -76,7 +76,7 @@ def test_load_hooks_py():
 
 def test_pep8_conformance():
     """Test that we conform to PEP-8."""
-    style = pycodestyle.StyleGuide(ignore=['E501', 'E402'])
+    style = pycodestyle.StyleGuide(ignore=['E501', 'E402', 'W503'])
 
     py_files = [y for x in os.walk(os.path.abspath('.')) for y in glob(os.path.join(x[0], '*.py'))]
     py_files.append(os.path.abspath('urlwatch'))
